==> ipymuvue-0.2.2.tar.gz: ipymuvue-0.2.2/setup.py <==
# ******************************************************************************
# Copyright (c) 2022 Julian Rüth <julian.rueth@fsfe.org>
#
# ipymuvue is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# ipymuvue is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ipymuvue. If not, see <https://www.gnu.org/licenses/>.
# ******************************************************************************

from __future__ import print_function
from setuptools import setup, find_packages
import os
from os.path import join as pjoin

from jupyter_packaging import (
    create_cmdclass,
    install_npm,
    ensure_targets,
    combine_commands,
)


here = os.path.dirname(os.path.abspath(__file__))

# The ts/ files are compiled automatically by the js/ prepublish command.
js_dir = pjoin(here, 'js')

# Representative files that should exist after a successful build
jstargets = [
    pjoin(js_dir, 'dist', 'index.js'),
]

data_files_spec = [
    ('share/jupyter/nbextensions/ipymuvue', 'ipymuvue/nbextension', '*.*'),
    ('share/jupyter/labextensions/ipymuvue', 'ipymuvue/labextension', "**"),
    ("share/jupyter/labextensions/ipymuvue", '.', "install.json"),
    ('etc/jupyter/nbconfig/notebook.d', '.', 'ipymuvue.json'),
]

cmdclass = create_cmdclass('jsdeps', data_files_spec=data_files_spec)
cmdclass['jsdeps'] = combine_commands(
    install_npm(js_dir, npm=['yarn'], build_cmd='build:prod'), ensure_targets(jstargets),
)

setup_args = dict(
    name='ipymuvue',
    version="0.2.2",
    description='Reactive Jupyter Widgets',
    long_description='Reactive Jupyter Widgets',
    include_package_data=True,
    install_requires=[
        'ipywidgets>=7,<9',
        'jupyter-ui-poll>=0.2.1,<0.3',
    ],
    packages=find_packages(),
    zip_safe=False,
    cmdclass=cmdclass,
    author='Julian Rüth',
    author_email='julian.rueth@fsfe.org',
    url='https://github.com/flatsurf/ipymuvue',
    keywords=[
        'ipython',
        'jupyter',
        'widgets',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: IPython',
        "License :: OSI Approved :: MIT License",
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)

setup(**setup_args)

==> ipymuvue-0.6.0.tar.gz: ipymuvue-0.6.0/setup.py <==
# ******************************************************************************
# Copyright (c) 2022 Julian Rüth <julian.rueth@fsfe.org>
#
# ipymuvue is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# ipymuvue is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with ipymuvue. If not, see <https://www.gnu.org/licenses/>.
# ******************************************************************************

from __future__ import print_function
from setuptools import setup, find_packages
import os
from os.path import join as pjoin

from jupyter_packaging import (
    create_cmdclass,
    install_npm,
    combine_commands,
)


here = os.path.dirname(os.path.abspath(__file__))

# The ts/ files are compiled automatically by the js/ prepublish command.
js_dir = pjoin(here, 'js')

data_files_spec = [
    ('share/jupyter/nbextensions/ipymuvue', 'ipymuvue/nbextension', '*.*'),
    ('share/jupyter/labextensions/ipymuvue', 'ipymuvue/labextension', "**"),
    ("share/jupyter/labextensions/ipymuvue", '.', "install.json"),
    ('etc/jupyter/nbconfig/notebook.d', '.', 'ipymuvue.json'),
]

cmdclass = create_cmdclass('jsdeps', data_files_spec=data_files_spec)
cmdclass['jsdeps'] = install_npm(js_dir, npm=['yarn'], build_cmd='build:prod')

setup_args = dict(
    name='ipymuvue',
    version="0.6.0",
    description='Reactive Jupyter Widgets',
    long_description='Reactive Jupyter Widgets',
    include_package_data=True,
    install_requires=[
        'ipywidgets>=7,<9',
        'jupyter-ui-poll>=0.2.1,<0.3',
    ],
    packages=find_packages(),
    zip_safe=False,
    cmdclass=cmdclass,
    author='Julian Rüth',
    author_email='julian.rueth@fsfe.org',
    url='https://github.com/flatsurf/ipymuvue',
    keywords=[
        'ipython',
        'jupyter',
        'widgets',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: IPython',
        "License :: OSI Approved :: MIT License",
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)

setup(**setup_args)
